/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/

#include "stdafx.h"
#include <windows.h>
#include <commctrl.h>

#include "gpioctl_v1.0.h"        // This defines the IOCTL constants.



int _tmain(int argc, _TCHAR* argv[])
{
	
		 // The following is returned by IOCTL.  It is true if the write succeeds.
    BOOL    IoctlResult;

    // The following parameters are used in the IOCTL call
    HANDLE              hndFile;        // Handle to device, obtain from CreateFile
    LONG                IoctlCode;
	UCHAR               DataValue;
    ULONG               DataLength;
    ULONG               ReturnedLength; // Number of bytes returned in output buffer

	// open the system service driver
	hndFile = CreateFile(
                    L"\\\\.\\WDGDev",           // Open the Device "file"
                    GENERIC_WRITE,
                    FILE_SHARE_WRITE,
                    NULL,
                    OPEN_EXISTING,
                    0,
                    NULL);

    if (hndFile == INVALID_HANDLE_VALUE)        // Was the device opened?
    {
        printf("Unable to open the device.\n");
        exit(1);
    }

	// starts watchdog timer
	DataValue=(DWORD)0x0+(DWORD)0xA; //Set watchdog timer in 60 seconds

	IoctlCode = IOCTL_START_WDG;

	DataLength=sizeof(DataValue);

    IoctlResult = DeviceIoControl(
                        hndFile,                // Handle to device
                        IoctlCode,              // IO Control code for Write
					    &DataValue,				// Buffer to driver.  Holds port & data.
                        DataLength,             // Length of buffer in bytes.
                        NULL,                   // Buffer from driver.   Not used.
                        0,                      // Length of buffer in bytes.
                        &ReturnedLength,        // Bytes placed in outbuf.  Should be 0.
                        NULL                    // NULL means wait till I/O completes.
                        );


    while ( TRUE )
	{
		printf( "Press \"ENTER\" in 10 seconds\n, 'q' to exit");
		WCHAR ch = getwchar();
		if ( ch == (WCHAR)'q' )
		{
			break;
		}

		// refresh watchdog timer
		IoctlCode = IOCTL_REFRESH_WDG;

		DataLength=sizeof(DataValue);

		IoctlResult = DeviceIoControl(
							hndFile,                // Handle to device
							IoctlCode,              // IO Control code for Write
							&DataValue,           // Buffer to driver.  Holds port & data.
							DataLength,             // Length of buffer in bytes.
							NULL,                   // Buffer from driver.   Not used.
							0,                      // Length of buffer in bytes.
							&ReturnedLength,        // Bytes placed in outbuf.  Should be 0.
							NULL                    // NULL means wait till I/O completes.
							);


		printf( "  *** fed *** \n");
	}

	// stops watchdog timer
	IoctlCode = IOCTL_STOP_WDG;
          
    IoctlResult = DeviceIoControl(
                        hndFile,                // Handle to device
                        IoctlCode,              // IO Control code for Write
					    NULL,					// Buffer to driver.  Holds port & data.
						0,						// Length of buffer in bytes.
                        NULL,                   // Buffer from driver.   Not used.
                        0,                      // Length of buffer in bytes.
                        &ReturnedLength,        // Bytes placed in outbuf.  Should be 0.
                        NULL                    // NULL means wait till I/O completes.
                        );


    
	// close the system service driver
	if (!CloseHandle(hndFile))                  // Close the Device "file".
    {
        printf("Failed to close device.\n");
    }

    exit(0);

	return 0;
}

